==> jc-1.4.0.tar.gz: soot/coffi/Main.h <==
// class soot.coffi.Main

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b0e643918ccb7e9e soot_coffi_Main

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_Main_H_
#define _JC_soot_coffi_Main_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_Main$sub_refs	_jc_soot_coffi_Main$sub_refs;
typedef struct _jc_soot_coffi_Main$sub_nonrefs	_jc_soot_coffi_Main$sub_nonrefs;
typedef struct _jc_soot_coffi_Main$refs	_jc_soot_coffi_Main$refs;
typedef struct _jc_soot_coffi_Main$nonrefs	_jc_soot_coffi_Main$nonrefs;
typedef struct _jc_soot_coffi_Main$object	_jc_soot_coffi_Main$object;

typedef const struct _jc_soot_coffi_Main$vmethods	_jc_soot_coffi_Main$vmethods;
typedef const struct _jc_soot_coffi_Main$vtable	_jc_soot_coffi_Main$vtable;
typedef const struct _jc_soot_coffi_Main$vtype	_jc_soot_coffi_Main$vtype;

// Constructors
extern void _jc_soot_coffi_Main$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Main$object *);

// Static methods
extern void _jc_soot_coffi_Main$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *);
extern void _jc_soot_coffi_Main$method$printClassInfo$016b0e751fdbfa48(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_soot_coffi_Main$vmethods {
};

// Vtable
struct _jc_soot_coffi_Main$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Main$vmethods	soot_coffi_Main;
};

// Vtype
struct _jc_soot_coffi_Main$vtype {
	_jc_type			type;
	_jc_soot_coffi_Main$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Main$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Main$refs {
    _jc_soot_coffi_Main$sub_refs	soot_coffi_Main;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Main$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Main$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Main$sub_nonrefs	soot_coffi_Main;
};

// Object instance structure
struct _jc_soot_coffi_Main$object {
	_jc_soot_coffi_Main$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Main$vtype	*vtype;
	_jc_soot_coffi_Main$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Main$vtype _jc_soot_coffi_Main$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Main, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Main$class_object;

#endif	/* _JC_soot_coffi_Main_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Main.h <==
// class soot.coffi.Main

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b0e643918ccb7e9e soot_coffi_Main

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_Main_H_
#define _JC_soot_coffi_Main_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_Main$sub_refs	_jc_soot_coffi_Main$sub_refs;
typedef struct _jc_soot_coffi_Main$sub_nonrefs	_jc_soot_coffi_Main$sub_nonrefs;
typedef struct _jc_soot_coffi_Main$refs	_jc_soot_coffi_Main$refs;
typedef struct _jc_soot_coffi_Main$nonrefs	_jc_soot_coffi_Main$nonrefs;
typedef struct _jc_soot_coffi_Main$object	_jc_soot_coffi_Main$object;

typedef const struct _jc_soot_coffi_Main$vmethods	_jc_soot_coffi_Main$vmethods;
typedef const struct _jc_soot_coffi_Main$vtable	_jc_soot_coffi_Main$vtable;
typedef const struct _jc_soot_coffi_Main$vtype	_jc_soot_coffi_Main$vtype;

// Constructors
extern void _jc_soot_coffi_Main$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Main$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_soot_coffi_Main$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_soot_coffi_Main$method$printClassInfo$016b0e751fdbfa48(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Main$vmethods {
};

// Vtable
struct _jc_soot_coffi_Main$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Main$vmethods	soot_coffi_Main;
};

// Vtype
struct _jc_soot_coffi_Main$vtype {
	_jc_type			type;
	_jc_soot_coffi_Main$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Main$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Main$refs {
    _jc_soot_coffi_Main$sub_refs	soot_coffi_Main;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Main$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Main$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Main$sub_nonrefs	soot_coffi_Main;
};

// Object instance structure
struct _jc_soot_coffi_Main$object {
	_jc_soot_coffi_Main$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Main$vtype	*vtype;
	_jc_soot_coffi_Main$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Main$vtype _jc_soot_coffi_Main$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Main, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Main$class_object;

#endif	/* _JC_soot_coffi_Main_H_ */
